/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log
{
    using System;
    using System.Collections.Generic;
    using System.Configuration;
    using System.Linq;
    using System.Text;
    using System.Xml;
    using System.Xml.XPath;

    using Phoenix.Log;

    /// <summary>
    /// Contains the information for the settings of assembly SQLiteAppender
    /// </summary>
    public class SQLiteAppenderHandler : AppenderHandler, IConfigurationSectionHandler
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteAppenderHandler"/> class.
        /// </summary>
        public SQLiteAppenderHandler()
        {
        }

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteAppenderHandler"/> class.
        /// </summary>
        /// <param name="dbPath">The db errorPath.</param>
        /// <param name="isActivated">if set to <c>true</c> [is activated].</param>
        /// <param name="logLevel">The log level.</param>
        /// <param name="silentError">if set to <c>true</c> error are silent.</param>
        protected SQLiteAppenderHandler(string dbPath, bool isActivated, int logLevel, bool silentError)
        {
            this.DatabasePath = dbPath;
            this.IsActivated = isActivated;
            this.LogLevel = logLevel;
            this.SilentError = silentError;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the database errorPath.
        /// </summary>
        /// <value>The database errorPath.</value>
        public string DatabasePath
        {
            get;
            private set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Creates assembly configuration section handler.
        /// </summary>
        /// <param name="parent">Parent object.</param>
        /// <param name="configContext">Configurator context object.</param>
        /// <param name="section">Section XML node.</param>
        /// <returns>The created section handler object.</returns>
        /// <exception cref="XPathException"></exception>
        /// <exception cref="ArgumentException"></exception>
        public object Create(object parent, object configContext, XmlNode section)
        {
            string activatedField = string.Empty;
            string logLevelField = string.Empty;
            string silentErrorField = string.Empty;

            #region Check arguments
            if (section == null)
                throw new ArgumentException("This argument shouldn't be null", "section");
            #endregion

            activatedField = section.SelectSingleNode("Activated").InnerText.ToLower();
            logLevelField = section.SelectSingleNode("LogLevel").InnerText;
            silentErrorField = section.SelectSingleNode("SilentError").InnerText;
            this.DatabasePath = section.SelectSingleNode("DbPath").InnerText;

            base.IsActivated = CheckIsActivated(activatedField);
            base.LogLevel = CheckLogLevel(logLevelField);
            base.SilentError = CheckSilentError(silentErrorField);

            return new SQLiteAppenderHandler(this.DatabasePath, this.IsActivated, this.LogLevel, this.SilentError);
        }

        #endregion Methods
    }
}