/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
namespace Phoenix.Log.Writer
{
    using System;

    /// <summary>
    /// An appender is an object that has to write the log into assembly container (can be assembly textWriter, assembly db, ...)
    /// </summary>
    public interface IAppender
    {
        #region Properties

        /// <summary>
        /// Gets or sets the log level.        
        ///  1- Log Fatal error only.
        ///  2- Log Error and above.
        ///  3- Log Warning and above.
        ///  4- Log Info and above.
        ///  5- Log Flag and above.
        ///  6- Log ALL.
        /// </summary>
        /// <remarks>If you dont want to log at all, set the IsActivated option to false
        /// to the appenders that don't have to log.</remarks>
        /// <value>The log level.</value>
        int LogLevel
        {
            get; set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether an error should be rethrown or silently
        /// logged into a textWriter.
        /// </summary>
        /// <value><c>true</c> if [silent error]; otherwise, <c>false</c>.</value>
        bool SilentError
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the type of sender.
        /// </summary>
        /// <value>The type of sender.</value>
        Type TypeOfSender
        {
            get;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Log assembly debug entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Debug(string message);

        /// <summary>
        /// Log assembly debug entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Debug(string message, Exception exception);

        /// <summary>
        /// Log an error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Error(string message);

        /// <summary>
        /// Log an error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Error(string message, Exception exception);

        /// <summary>
        /// Log assembly fatal error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>        
        void Fatal(string message);

        /// <summary>
        /// Log assembly fatal error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Fatal(string message, Exception exception);

        /// <summary>
        /// Log assembly flag into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Flag(string message);

        /// <summary>
        /// Log assembly flag into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Flag(string message, Exception exception);

        /// <summary>
        /// Log assembly info entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Info(string message);

        /// <summary>
        /// Log assembly info entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Info(string message, Exception exception);

        /// <summary>
        /// Inserts the specified error entry.
        /// </summary>
        /// <param name="logRow">The log row.</param>
        void Insert(IRow logRow);

        /// <summary>
        /// Sets the type of sender.
        /// </summary>
        /// <param name="typeOfSender">The type of sender.</param>
        void SetTypeOfSender(Type typeOfSender);

        /// <summary>
        /// Log assembly warning into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Warning(string message);

        /// <summary>
        /// Log assembly warning into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Warning(string message, Exception exception);

        #endregion Methods
    }
}