/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// The Log is assembly container of <see cref="Log.Writer.IAppender"/> each call of assembly writing
    /// log method will execute the same method of all appenders contained into this Log class
    /// </summary>
    public class Logger : ILogger
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="Log"/> class.
        /// </summary>
        internal Logger()
        {
            this.Appenders = new List<IAppender>();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the list of appenders.
        /// </summary>
        /// <value>The appenders.</value>
        public List<IAppender> Appenders
        {
            get;
            private set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Adds an appender.
        /// </summary>
        /// <param name="appender">The appender.</param>
        public void AddAppender(IAppender appender)
        {
            this.Appenders.Add(appender);
        }

        /// <summary>
        /// Log assembly debug entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        public void Debug(string message)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Debug(message);
            }
        }

        /// <summary>
        /// Log assembly debug entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        public void Debug(string message, Exception exception)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Debug(message, exception);
            }
        }

        /// <summary>
        /// Log an error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        public void Error(string message)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Error(message);
            }
        }

        /// <summary>
        /// Log an error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        public void Error(string message, Exception exception)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Error(message, exception);
            }
        }

        /// <summary>
        /// Log assembly fatal error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        public void Fatal(string message)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Fatal(message);
            }
        }

        /// <summary>
        /// Log assembly fatal error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        public void Fatal(string message, Exception exception)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Fatal(message, exception);
            }
        }

        /// <summary>
        /// Log assembly flag into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        public void Flag(string message)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Flag(message);
            }
        }

        /// <summary>
        /// Log assembly flag into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        public void Flag(string message, Exception exception)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Flag(message, exception);
            }
        }

        /// <summary>
        /// Log assembly info entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        public void Info(string message)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Info(message);
            }
        }

        /// <summary>
        /// Log assembly info entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        public void Info(string message, Exception exception)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Info(message, exception);
            }
        }

        /// <summary>
        /// Inserts the specified error entry.
        /// </summary>
        /// <param name="errorEntry">The error entry.</param>
        public void Insert(IRow errorEntry)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Insert(errorEntry);
            }
        }

        /// <summary>
        /// Removes the specified appender from the list of appenders.
        /// </summary>
        /// <param name="appender">The appender.</param>
        /// <returns>
        /// 	<c>true</c> if the deletion succeded. Otherwise <c>false</c>
        /// </returns>
        public bool RemoveAppender(IAppender appender)
        {
            return this.Appenders.Remove(appender);
        }

        /// <summary>
        /// Sets the type of sender.
        /// </summary>
        /// <param name="typeOfSender">The type of sender.</param>
        public void SetTypeOfSender(Type typeOfSender)
        {
            for (int i = 0; i < this.Appenders.Count; i++)
            {
                this.Appenders[i].SetTypeOfSender(typeOfSender);
            }
        }

        /// <summary>
        /// Log assembly warning into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        public void Warning(string message)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Warning(message);
            }
        }

        /// <summary>
        /// Warnings the specified message.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        public void Warning(string message, Exception exception)
        {
            foreach (IAppender appender in Appenders)
            {
                appender.Warning(message, exception);
            }
        }

        #endregion Methods

        #region Other

        ///// <summary>
        ///// Initializes assembly new instance of the <see cref="Log"/> class.
        ///// </summary>
        ///// <param name="appenders">The appenders.</param>
        //internal Logger(List<IAppender> appenders)
        //    : this()
        //{
        //    this.Appenders = appenders;
        //}

        #endregion Other
    }
}